@@ -247,6 +247,8 @@ TEMP_CACHE_DIR_PREFIX = "hf_datasets-"
 # Streaming
 STREAMING_READ_MAX_RETRIES = 20
 STREAMING_READ_RETRY_INTERVAL = 5
+STREAMING_OPEN_MAX_RETRIES = 20
+STREAMING_OPEN_RETRY_INTERVAL = 5
 
 # Datasets repositories exploration
 DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 200
